<?php
/**
 * Blog Town functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package blog_town
 */

if ( ! defined( 'BLOG_TOWN_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'BLOG_TOWN_S_VERSION', '1.0.3' );
}

if ( ! function_exists( 'blog_town_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function blog_town_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Blog Town, use a find and replace
		 * to change 'blog-town' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'blog-town', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary'  => esc_html__( 'Primary Menu', 'blog-town' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support('custom-background', apply_filters(
				'blog_town_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Image size for single posts
		add_image_size( 'slider-post-thumbnail', 802, 630 );

		add_theme_support( 'align-wide' );

		add_theme_support('editor-styles');
		
		add_theme_support( 'wp-block-styles' );

		// Enable support for custom logo.
		add_theme_support( 'custom-logo' , array(
			'height'		=>45,	
			'width'			=>45,	
			'flex-height'	=>true,	
			'flex-width'	=>true,
		));
		
		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );


		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'blog_town_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function blog_town_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'blog_town_content_width', 640 );
}
add_action( 'after_setup_theme', 'blog_town_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function blog_town_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Blog Sidebar', 'blog-town' ),
			'id'            => 'sidebar-main',
			'description'   => esc_html__( 'Add widgets here.', 'blog-town' ),
			'before_widget' => '<section id="%1$s" class="widget widget_block %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer Widgets', 'blog-town' ),
			'id'            => 'footer-widgets',
			'description'   => __( 'Add widgets here.', 'blog-town' ),
			'before_widget' => '<div class="%2$s footer-widget col-md-3 col-sm-6 col-xs-12">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="sidebar-title"><h3 class="widget-title mb-20">',
			'after_title'   => '</h3></div>',
		)
	);
}
add_action( 'widgets_init', 'blog_town_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function blog_town_scripts() {

	wp_enqueue_style('bootstrap-css', get_template_directory_uri() . '/assets/css/bootstrap.css');
	wp_enqueue_style('font-awesome-css', get_template_directory_uri() . '/assets/css/all.css');
	wp_enqueue_style('slick-css', get_template_directory_uri() . '/assets/css/slick.css');
	wp_enqueue_style('meanmenu-css', get_template_directory_uri() . '/assets/css/meanmenu.css');
	wp_enqueue_style('blog-town-default-css', get_template_directory_uri() . '/assets/css/default.css');
	wp_enqueue_style('blog-town-responsive-css', get_template_directory_uri() . '/assets/css/responsive.css');
	wp_enqueue_style('blog-town-custom-css', get_template_directory_uri() . '/assets/css/custom.css');

	wp_enqueue_style( 'blog-town-style', get_stylesheet_uri(), array(), BLOG_TOWN_S_VERSION );
	wp_style_add_data( 'blog-town-style', 'rtl', 'replace' );

	wp_enqueue_script( 'blog-town-navigation', get_template_directory_uri() . '/js/navigation.js', array(), BLOG_TOWN_S_VERSION, true );

	wp_enqueue_script( 'popper-js', get_template_directory_uri() . '/assets/js/popper.js',array('jquery'), BLOG_TOWN_S_VERSION, true );
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/assets/js/bootstrap.js',array(), BLOG_TOWN_S_VERSION, true );
	wp_enqueue_script( 'slick-js', get_template_directory_uri() . '/assets/js/slick.js',array(), BLOG_TOWN_S_VERSION, true );
	wp_enqueue_script( 'jquery-scrollUp-js', get_template_directory_uri() . '/assets/js/jquery.scrollUp.js',array(), BLOG_TOWN_S_VERSION, true );
	wp_enqueue_script( 'jquery-meanmenu-js', get_template_directory_uri() . '/assets/js/jquery.meanmenu.js',array(), BLOG_TOWN_S_VERSION, true );
	wp_enqueue_script( 'blog-town-main-js', get_template_directory_uri() . '/assets/js/main.js',array(), BLOG_TOWN_S_VERSION, true );
	wp_enqueue_script( 'blog-town-menu-modal', get_template_directory_uri() . '/assets/js/menu-accessibility.js',array(), BLOG_TOWN_S_VERSION, true );
        
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'blog_town_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

require get_template_directory() . '/inc/controls.php';

require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}